Configuration
==================

Animanager uses a configuration file in INI format.  The default path of the
file is ``~/.animanager/config.ini``, but can also be supplied as an option in
the command line.

See the included ``config.ini`` file for documentation and defaults.
